UPIRequestParameters class

Constructors

UPIRequestParameters.builder(dynamic buildFunc(UPIRequestBuilder))
factory

Properties

amount ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payeeMerchantCode ↔ String?
getter/setter pair
payeeName ↔ String?
getter/setter pair
payeeVpa ↔ String?
getter/setter pair
paymentApp ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionId ↔ String?
getter/setter pair
transactionRefId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited